@@ -20,8 +20,12 @@ class OKTETAKASTENCONTROLLERS_EXPORT ChecksumToolViewFactory : public AbstractTo
 {
 public:
     ChecksumToolViewFactory();
+    ChecksumToolViewFactory(const ChecksumToolViewFactory&) = delete;
+
     ~ChecksumToolViewFactory() override;
 
+    ChecksumToolViewFactory& operator=(const ChecksumToolViewFactory&) = delete;
+
 public: // AbstractToolViewFactory API
     AbstractToolView* create(AbstractTool* tool) const override;
 
