@@ -32,7 +32,7 @@ inline PrimitiveArrayData<type>::PrimitiveArrayData(unsigned int initialLength,
 }
 
 template <PrimitiveDataType type>
-qint64 PrimitiveArrayData<type>::readData(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
+qint64 PrimitiveArrayData<type>::readData(const Okteta::AbstractByteArrayModel* input, Okteta::Address address,
                                           BitCount64 bitsRemaining)
 {
     Q_ASSERT(bitsRemaining % 8 == 0);
@@ -60,7 +60,8 @@ qint64 PrimitiveArrayData<type>::readData(Okteta::AbstractByteArrayModel* input,
 }
 
 template <PrimitiveDataType type>
-void PrimitiveArrayData<type>::readDataNativeOrder(uint numItems, Okteta::AbstractByteArrayModel* input,
+void PrimitiveArrayData<type>::readDataNativeOrder(uint numItems,
+                                                   const Okteta::AbstractByteArrayModel* input,
                                                    Okteta::Address address)
 {
     Q_ASSERT(numItems <= length());
@@ -74,7 +75,8 @@ void PrimitiveArrayData<type>::readDataNativeOrder(uint numItems, Okteta::Abstra
 }
 
 template <PrimitiveDataType type>
-void PrimitiveArrayData<type>::readDataNonNativeOrder(uint numItems, Okteta::AbstractByteArrayModel* input,
+void PrimitiveArrayData<type>::readDataNonNativeOrder(uint numItems,
+                                                      const Okteta::AbstractByteArrayModel* input,
                                                       Okteta::Address address)
 {
     Q_ASSERT(numItems <= length());
@@ -231,6 +233,12 @@ QString PrimitiveArrayData<type>::typeName() const
                    + QString::number(this->length()) + QLatin1Char(']'));
 }
 
+template <PrimitiveDataType type>
+QString PrimitiveArrayData<type>::valueString() const
+{
+    return QString();
+}
+
 template <PrimitiveDataType type>
 int PrimitiveArrayData<type>::indexOf(const DataInformation* data) const
 {
@@ -275,6 +283,22 @@ void PrimitiveArrayData<type>::setChildWidgetData(uint index, QWidget* w) const
     DisplayClass::staticSetWidgetData(mData.at(index), w);
 }
 
+template <>
+QString PrimitiveArrayData<PrimitiveDataType::Char>::valueString() const
+{
+    QString result;
+    result.reserve(length());
+    for (uint index = 0; index < length(); ++index) {
+        QChar qchar(mData.at(index), 0);
+        if (!qchar.isPrint()) {
+            qchar = QChar(QChar::ReplacementCharacter);
+        }
+        result.append(qchar);
+    }
+    return result;
+}
+
+
 // now instantiate all the template instances
 template class PrimitiveArrayData<PrimitiveDataType::Bool8>;
 template class PrimitiveArrayData<PrimitiveDataType::Bool16>;
