@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2009, 2022 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -11,6 +11,8 @@
 // Okteta core
 #include <Okteta/AbstractByteArrayModel>
 // KF
+#include <KConfigGroup>
+#include <KSharedConfig>
 #include <KLocalizedString>
 // Qt
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
@@ -25,8 +27,28 @@
 
 namespace Kasten {
 
+static constexpr int DefaultSize = 256;
+
+static constexpr char ByteArrayRandomDataGeneratorConfigGroupId[] = "ByteArrayRandomDataGenerator";
+static constexpr char SizeConfigKey[] = "Size";
+
 ByteArrayRandomDataGeneratorSettings::ByteArrayRandomDataGeneratorSettings() = default;
 
+bool ByteArrayRandomDataGeneratorSettings::operator==(const ByteArrayRandomDataGeneratorSettings& other) const
+{
+    return (size == other.size);
+}
+
+void ByteArrayRandomDataGeneratorSettings::loadConfig(const KConfigGroup& configGroup)
+{
+    size = configGroup.readEntry(SizeConfigKey, DefaultSize);
+}
+
+void ByteArrayRandomDataGeneratorSettings::saveConfig(KConfigGroup& configGroup) const
+{
+    configGroup.writeEntry(SizeConfigKey, size);
+}
+
 // TODO: support insert to selection, cmp. fill in painting program
 // there are two kinds of generated datam fixed size (e.g. sequence) and endless size?
 // perhaps by option fill selection? or a separate menu entry fill, which only works on selections?
@@ -36,10 +58,27 @@ ByteArrayRandomDataGenerator::ByteArrayRandomDataGenerator()
         i18nc("name of the generated data", "Random Data..."),
         QStringLiteral("application/octet-stream"),
         DynamicGeneration)
-{}
+{
+    const KConfigGroup configGroup(KSharedConfig::openConfig(), ByteArrayRandomDataGeneratorConfigGroupId);
+
+    mSettings.loadConfig(configGroup);
+}
 
 ByteArrayRandomDataGenerator::~ByteArrayRandomDataGenerator() = default;
 
+void ByteArrayRandomDataGenerator::setSettings(const ByteArrayRandomDataGeneratorSettings& settings)
+{
+    if (mSettings == settings) {
+        return;
+    }
+
+    mSettings = settings;
+
+    KConfigGroup configGroup(KSharedConfig::openConfig(), ByteArrayRandomDataGeneratorConfigGroupId);
+    mSettings.saveConfig(configGroup);
+//     emit settingsChanged();
+}
+
 // TODO: use different RNG, with multiple characteristics and offer them in the config
 QMimeData* ByteArrayRandomDataGenerator::generateData()
 {
@@ -83,3 +122,5 @@ QMimeData* ByteArrayRandomDataGenerator::generateData()
 }
 
 }
+
+#include "moc_bytearrayrandomdatagenerator.cpp"
